pytilities.aop.aspects.immutableaspect — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »
- pytilities.aop.aspects »

# pytilities.aop.aspects.immutableaspect

class `pytilities.aop.aspects.immutableaspect.` `ImmutableAspect`(attributes)

  Aspect that makes some attributes immutable

  `__init__`(attributes)

    Create an ImmutableAspect.

    Parameters: | attributes (iter(str, ...)) – Attribute names whose setters to guard

  `_fail`()

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »
- pytilities.aop.aspects »